audiofile
=========

.. automodule:: audiofile

.. autosummary::
    :toctree:
    :nosignatures:

    read
    write
    bit_depth
    channels
    duration
    has_video
    samples
    sampling_rate
    convert_to_wav
